Package {AvatarTLA}


Type: Package
Title: Color Palettes from 'Avatar: The Last Airbender'
Version: 0.1.0
Description: Color palettes inspired by characters and nations from the animated series 'Avatar: The Last Airbender' for use in R graphics.
License: MIT + file LICENSE
Encoding: UTF-8
Imports: graphics, grDevices
RoxygenNote: 7.3.3
URL: https://github.com/Gerardo-Manzanarez-Villasana/AvatarTLA
BugReports: https://github.com/Gerardo-Manzanarez-Villasana/AvatarTLA/issues
Language: en-US
NeedsCompilation: no
Packaged: 2026-08-22 01:04:22 UTC; Gerardo Manzanarez
Author: Gerardo Manzanarez-Villasana [aut, cre]
Maintainer: Gerardo Manzanarez-Villasana <jupiter.gmv@gmail.com>
Repository: CRAN
Date/Publication: 2026-09-01 14:00:29 UTC

AvatarTLA: Color Palettes Inspired by Avatar: The Last Airbender

Description

Color palettes inspired by characters and nations from the animated series Avatar: The Last Airbender for use in R graphics.

Details

Color palettes inspired by characters and nations from the animated series Avatar: The Last Airbender for use in R graphics.

Author(s)

Maintainer: Gerardo Manzanarez-Villasana jupiter.gmv@gmail.com

See Also

Useful links:


An Avatar: The Last Airbender palette generator

Description

Color palettes inspired by characters and nations from Avatar: The Last Airbender.

Usage

avatar_palette(name, n, type = c("discrete", "continuous"))

Arguments

name

Name of desired palette. Choices are: Mai, Suki, Iroh, FireNation, AirNomads, EarthKingdom, WaterTribe, Appa, Sokka, Toph, Azula, Aang, Zuko, Katara, Ty, Momo

n

Number of desired colors. If omitted, uses all colors from the palette.

type

Either "discrete" or "continuous". Use continuous if you want to automatically interpolate between colors.

Value

A vector of colors.

Examples

avatar_palette("Toph")
avatar_palette("Aang", 3)
avatar_palette("EarthKingdom", 30, type = "continuous")

Complete list of Avatar palettes

Description

Use avatar_palette to construct palettes of desired length.

Usage

avatar_palettes

Format

An object of class list of length 16.